@@ -17,7 +17,7 @@ use strict;
 @ISA = qw(Verilog::Netlist::Module::Struct
 	Verilog::Netlist::Subclass);
 
-$VERSION = '3.315';
+$VERSION = '3.401';
 
 structs('new',
 	'Verilog::Netlist::Module::Struct'
@@ -456,6 +456,10 @@ Returns Verilog::Netlist::Port matching given name.
 
 Returns Verilog::Netlist::Net matching given name.
 
+=item $self->is_libcell
+
+Returns if module declared inside a `celldefine.
+
 =item $self->level
 
 Returns the reverse depth of this module with respect to other modules.
@@ -506,7 +510,7 @@ Verilog-Perl is part of the L<http://www.veripool.org/> free Verilog EDA
 software tool suite.  The latest version is available from CPAN and from
 L<http://www.veripool.org/verilog-perl>.
 
-Copyright 2000-2012 by Wilson Snyder.  This package is free software; you
+Copyright 2000-2013 by Wilson Snyder.  This package is free software; you
 can redistribute it and/or modify it under the terms of either the GNU
 Lesser General Public License Version 3 or the Perl Artistic License Version 2.0.
 
